@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
 # BSD 2-Clause License
 #
 # Apprise - Push Notification Library.
-# Copyright (c) 2024, Chris Caron <lead2gold@gmail.com>
+# Copyright (c) 2025, Chris Caron <lead2gold@gmail.com>
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -26,32 +25,31 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-import requests
 from json import dumps
 
-from .base import NotifyBase
-from ..url import PrivacyMode
+import requests
+
 from ..common import NotifyType
-from ..utils.parse import validate_regex
 from ..locale import gettext_lazy as _
+from ..url import PrivacyMode
+from ..utils.parse import validate_regex
+from .base import NotifyBase
 
 
 class NotifyPushjet(NotifyBase):
-    """
-    A wrapper for Pushjet Notifications
-    """
+    """A wrapper for Pushjet Notifications."""
 
     # The default descriptive name associated with the Notification
-    service_name = 'Pushjet'
+    service_name = "Pushjet"
 
     # The default protocol
-    protocol = 'pjet'
+    protocol = "pjet"
 
     # The default secure protocol
-    secure_protocol = 'pjets'
+    secure_protocol = "pjets"
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = 'https://github.com/caronc/apprise/wiki/Notify_pushjet'
+    setup_url = "https://appriseit.com/services/pushjet/"
 
     # Disable throttle rate for Pushjet requests since they are normally
     # local anyway (the remote/online service is no more)
@@ -59,59 +57,64 @@ class NotifyPushjet(NotifyBase):
 
     # Define object templates
     templates = (
-        '{schema}://{host}:{port}/{secret_key}',
-        '{schema}://{host}/{secret_key}',
-        '{schema}://{user}:{password}@{host}:{port}/{secret_key}',
-        '{schema}://{user}:{password}@{host}/{secret_key}',
+        "{schema}://{host}:{port}/{secret_key}",
+        "{schema}://{host}/{secret_key}",
+        "{schema}://{user}:{password}@{host}:{port}/{secret_key}",
+        "{schema}://{user}:{password}@{host}/{secret_key}",
     )
 
     # Define our tokens
-    template_tokens = dict(NotifyBase.template_tokens, **{
-        'host': {
-            'name': _('Hostname'),
-            'type': 'string',
-            'required': True,
+    template_tokens = dict(
+        NotifyBase.template_tokens,
+        **{
+            "host": {
+                "name": _("Hostname"),
+                "type": "string",
+                "required": True,
+            },
+            "port": {
+                "name": _("Port"),
+                "type": "int",
+                "min": 1,
+                "max": 65535,
+            },
+            "secret_key": {
+                "name": _("Secret Key"),
+                "type": "string",
+                "required": True,
+                "private": True,
+            },
+            "user": {
+                "name": _("Username"),
+                "type": "string",
+            },
+            "password": {
+                "name": _("Password"),
+                "type": "string",
+                "private": True,
+            },
         },
-        'port': {
-            'name': _('Port'),
-            'type': 'int',
-            'min': 1,
-            'max': 65535,
-        },
-        'secret_key': {
-            'name': _('Secret Key'),
-            'type': 'string',
-            'required': True,
-            'private': True,
-        },
-        'user': {
-            'name': _('Username'),
-            'type': 'string',
-        },
-        'password': {
-            'name': _('Password'),
-            'type': 'string',
-            'private': True,
-        },
-    })
+    )
 
-    template_args = dict(NotifyBase.template_args, **{
-        'secret': {
-            'alias_of': 'secret_key',
+    template_args = dict(
+        NotifyBase.template_args,
+        **{
+            "secret": {
+                "alias_of": "secret_key",
+            },
         },
-    })
+    )
 
     def __init__(self, secret_key, **kwargs):
-        """
-        Initialize Pushjet Object
-        """
+        """Initialize Pushjet Object."""
         super().__init__(**kwargs)
 
         # Secret Key (associated with project)
         self.secret_key = validate_regex(secret_key)
         if not self.secret_key:
-            msg = 'An invalid Pushjet Secret Key ' \
-                  '({}) was specified.'.format(secret_key)
+            msg = (
+                f"An invalid Pushjet Secret Key ({secret_key}) was specified."
+            )
             self.logger.warning(msg)
             raise TypeError(msg)
 
@@ -119,20 +122,22 @@ class NotifyPushjet(NotifyBase):
 
     @property
     def url_identifier(self):
-        """
-        Returns all of the identifiers that make this URL unique from
-        another simliar one. Targets or end points should never be identified
-        here.
+        """Returns all of the identifiers that make this URL unique from
+        another simliar one.
+
+        Targets or end points should never be identified here.
         """
         return (
             self.secure_protocol if self.secure else self.protocol,
-            self.user, self.password, self.host, self.port, self.secret_key,
+            self.user,
+            self.password,
+            self.host,
+            self.port,
+            self.secret_key,
         )
 
     def url(self, privacy=False, *args, **kwargs):
-        """
-        Returns the URL built dynamically based on specified arguments.
-        """
+        """Returns the URL built dynamically based on specified arguments."""
 
         # Our URL parameters
         params = self.url_parameters(privacy=privacy, *args, **kwargs)
@@ -140,61 +145,66 @@ class NotifyPushjet(NotifyBase):
         default_port = 443 if self.secure else 80
 
         # Determine Authentication
-        auth = ''
+        auth = ""
         if self.user and self.password:
-            auth = '{user}:{password}@'.format(
-                user=NotifyPushjet.quote(self.user, safe=''),
+            auth = "{user}:{password}@".format(
+                user=NotifyPushjet.quote(self.user, safe=""),
                 password=self.pprint(
-                    self.password, privacy, mode=PrivacyMode.Secret, safe=''),
+                    self.password, privacy, mode=PrivacyMode.Secret, safe=""
+                ),
             )
 
-        return '{schema}://{auth}{hostname}{port}/{secret}/?{params}'.format(
+        return "{schema}://{auth}{hostname}{port}/{secret}/?{params}".format(
             schema=self.secure_protocol if self.secure else self.protocol,
             auth=auth,
             # never encode hostname since we're expecting it to be a valid one
             hostname=self.host,
-            port='' if self.port is None or self.port == default_port
-                 else ':{}'.format(self.port),
+            port=(
+                ""
+                if self.port is None or self.port == default_port
+                else f":{self.port}"
+            ),
             secret=self.pprint(
-                self.secret_key, privacy, mode=PrivacyMode.Secret, safe=''),
+                self.secret_key, privacy, mode=PrivacyMode.Secret, safe=""
+            ),
             params=NotifyPushjet.urlencode(params),
         )
 
-    def send(self, body, title='', notify_type=NotifyType.INFO, **kwargs):
-        """
-        Perform Pushjet Notification
-        """
+    def send(self, body, title="", notify_type=NotifyType.INFO, **kwargs):
+        """Perform Pushjet Notification."""
 
         params = {
-            'secret': self.secret_key,
+            "secret": self.secret_key,
         }
 
         # prepare Pushjet Object
         payload = {
-            'message': body,
-            'title': title,
-            'link': None,
-            'level': None,
+            "message": body,
+            "title": title,
+            "link": None,
+            "level": None,
         }
 
         headers = {
-            'User-Agent': self.app_id,
-            'Content-Type': 'application/x-www-form-urlencoded; charset=utf-8',
+            "User-Agent": self.app_id,
+            "Content-Type": "application/x-www-form-urlencoded; charset=utf-8",
         }
 
         auth = None
         if self.user:
             auth = (self.user, self.password)
 
-        notify_url = '{schema}://{host}{port}/message/'.format(
+        notify_url = "{schema}://{host}{port}/message/".format(
             schema="https" if self.secure else "http",
             host=self.host,
-            port=':{}'.format(self.port) if self.port else '')
+            port=f":{self.port}" if self.port else "",
+        )
 
-        self.logger.debug('Pushjet POST URL: %s (cert_verify=%r)' % (
-            notify_url, self.verify_certificate,
-        ))
-        self.logger.debug('Pushjet Payload: %s' % str(payload))
+        self.logger.debug(
+            "Pushjet POST URL:"
+            f" {notify_url} (cert_verify={self.verify_certificate!r})"
+        )
+        self.logger.debug(f"Pushjet Payload: {payload!s}")
 
         # Always call throttle before any remote server i/o is made
         self.throttle()
@@ -211,29 +221,32 @@ class NotifyPushjet(NotifyBase):
             )
             if r.status_code != requests.codes.ok:
                 # We had a problem
-                status_str = \
-                    NotifyPushjet.http_response_code_lookup(r.status_code)
+                status_str = NotifyPushjet.http_response_code_lookup(
+                    r.status_code
+                )
 
                 self.logger.warning(
-                    'Failed to send Pushjet notification: '
-                    '{}{}error={}.'.format(
-                        status_str,
-                        ', ' if status_str else '',
-                        r.status_code))
+                    "Failed to send Pushjet notification: "
+                    "{}{}error={}.".format(
+                        status_str, ", " if status_str else "", r.status_code
+                    )
+                )
 
-                self.logger.debug('Response Details:\r\n{}'.format(r.content))
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 # Return; we're done
                 return False
 
             else:
-                self.logger.info('Sent Pushjet notification.')
+                self.logger.info("Sent Pushjet notification.")
 
         except requests.RequestException as e:
             self.logger.warning(
-                'A Connection error occurred sending Pushjet '
-                'notification to %s.' % self.host)
-            self.logger.debug('Socket Exception: %s' % str(e))
+                "A Connection error occurred sending Pushjet "
+                f"notification to {self.host}."
+            )
+            self.logger.debug(f"Socket Exception: {e!s}")
 
             # Return; we're done
             return False
@@ -242,9 +255,8 @@ class NotifyPushjet(NotifyBase):
 
     @staticmethod
     def parse_url(url):
-        """
-        Parses the URL and returns enough arguments that can allow
-        us to re-instantiate this object.
+        """Parses the URL and returns enough arguments that can allow us to re-
+        instantiate this object.
 
         Syntax:
            pjet://hostname/secret_key
@@ -263,18 +275,20 @@ class NotifyPushjet(NotifyBase):
 
         try:
             # Retrieve our secret_key from the first entry in the url path
-            results['secret_key'] = \
-                NotifyPushjet.split_path(results['fullpath'])[0]
+            results["secret_key"] = NotifyPushjet.split_path(
+                results["fullpath"]
+            )[0]
 
         except IndexError:
             # no secret key specified
-            results['secret_key'] = None
+            results["secret_key"] = None
 
         # Allow over-riding the secret by specifying it as an argument
         # this allows people who have http-auth infront to login
         # through it in addition to supporting the secret key
-        if 'secret' in results['qsd'] and len(results['qsd']['secret']):
-            results['secret_key'] = \
-                NotifyPushjet.unquote(results['qsd']['secret'])
+        if "secret" in results["qsd"] and len(results["qsd"]["secret"]):
+            results["secret_key"] = NotifyPushjet.unquote(
+                results["qsd"]["secret"]
+            )
 
         return results
