@@ -30,6 +30,7 @@ from json import dumps, loads
 # Disable logging for a cleaner testing output
 import logging
 import os
+from typing import Union
 from unittest import mock
 
 from helpers import AppriseURLTester
@@ -208,7 +209,8 @@ apprise_url_tests = (
         },
     ),
     (
-        "matrixs://user:token@localhost?mode=slack&format=markdown&image=False",
+        ("matrixs://user:token@localhost?mode=slack"
+         "&format=markdown&image=False"),
         {
             # user and token specified; image set to True
             "instance": NotifyMatrix,
@@ -585,8 +587,8 @@ def test_plugin_matrix_fetch(mock_post, mock_get, mock_put):
         "retry_after_ms": 1,
     })
 
-    code, _response = obj._fetch("/retry/apprise/unit/test")
-    assert code is False
+    postokay, _response, _ = obj._fetch("/retry/apprise/unit/test")
+    assert postokay is False
 
     request.content = dumps(
         {
@@ -595,12 +597,12 @@ def test_plugin_matrix_fetch(mock_post, mock_get, mock_put):
             }
         }
     )
-    code, _response = obj._fetch("/retry/apprise/unit/test")
-    assert code is False
+    postokay, _response, _ = obj._fetch("/retry/apprise/unit/test")
+    assert postokay is False
 
     request.content = dumps({"error": {}})
-    code, _response = obj._fetch("/retry/apprise/unit/test")
-    assert code is False
+    postokay, _response, _ = obj._fetch("/retry/apprise/unit/test")
+    assert postokay is False
     del obj
 
 
@@ -1760,6 +1762,7 @@ def test_plugin_matrix_transaction_ids_api_v3_w_cache(
         assert mock_post.call_count == 0
         assert mock_put.call_count == 0
 
+
 @mock.patch("requests.put")
 @mock.patch("requests.get")
 @mock.patch("requests.post")
@@ -1841,3 +1844,140 @@ def test_plugin_matrix_v3_url_with_port_assembly(
 
     # Cleanup
     del obj
+
+
+@mock.patch("requests.put")
+@mock.patch("requests.get")
+@mock.patch("requests.post")
+def test_plugin_matrix_no_room_create_on_non_not_found_join(
+    mock_post: mock.Mock,
+    mock_get: mock.Mock,
+    mock_put: mock.Mock,
+) -> None:
+    """No room creation when join fails with 400 (or other non-404).
+
+    A join failure can occur for many reasons, such as auth failure or invite
+    required. In these cases, attempting to create the room is incorrect and
+    produces misleading follow-up errors like M_ROOM_IN_USE.
+    """
+
+    def _resp(status_code: int, content: Union[str, bytes]) -> mock.Mock:
+        r = mock.Mock()
+        r.status_code = status_code
+        if isinstance(content, str):
+            r.content = content.encode("utf-8")
+        else:
+            r.content = content
+        return r
+
+    login = dumps(
+        {
+            "access_token": "t",
+            "home_server": "hs",
+            "user_id": "@u:hs",
+        }
+    )
+
+    # POST sequence:
+    # 1. /login succeeds
+    # 2. /join/#backup fails with 400 and an empty body
+    # 3. /logout succeeds during object cleanup remembering token
+    mock_post.side_effect = [
+        _resp(requests.codes.ok, login),
+        _resp(requests.codes.bad_request, b""),
+        _resp(requests.codes.ok, dumps({})),
+    ]
+
+    # No other requests should be needed (no createRoom, no directory lookup)
+    mock_get.return_value = _resp(requests.codes.internal_server_error, b"")
+    mock_put.return_value = _resp(requests.codes.ok, dumps({}))
+
+    ap = Apprise()
+    ap.add("matrixs://user:pass@matrix.vip/#backup?discovery=no")
+
+    assert ap.notify(title="t", body="b") is False
+
+    # Cleanup explicitly to ensure __del__ executes while mocks are active.
+    import gc
+
+    del ap
+    gc.collect()
+
+    # login + join + logout
+    assert mock_post.call_count == 3
+    assert mock_get.call_count == 0
+
+
+@mock.patch("requests.put")
+@mock.patch("requests.get")
+@mock.patch("requests.post")
+def test_plugin_matrix_room_create_on_not_found_join(
+    mock_post: mock.Mock,
+    mock_get: mock.Mock,
+    mock_put: mock.Mock,
+) -> None:
+    """Attempt room creation only when join reports 404 / M_NOT_FOUND."""
+
+    def _resp(status_code: int, content: Union[str, bytes]) -> mock.Mock:
+        r = mock.Mock()
+        r.status_code = status_code
+        if isinstance(content, str):
+            r.content = content.encode("utf-8")
+        else:
+            r.content = content
+        return r
+
+    login = dumps(
+        {
+            "access_token": "t",
+            "home_server": "hs",
+            "user_id": "@u:hs",
+        }
+    )
+
+    # POST sequence:
+    # 1. /login succeeds
+    # 2. /join/#backup returns 404 not found
+    # 3. /createRoom returns alias in use, triggering alias resolution
+    # 4. /logout succeeds during object cleanup
+    mock_post.side_effect = [
+        _resp(requests.codes.ok, login),
+        _resp(
+            requests.codes.not_found,
+            dumps({"errcode": "M_NOT_FOUND", "error": "Not found"}),
+        ),
+        _resp(
+            requests.codes.bad_request,
+            dumps(
+                {
+                    "errcode": "M_ROOM_IN_USE",
+                    "error": "Room alias already taken",
+                }
+            ),
+        ),
+        _resp(requests.codes.ok, dumps({})),
+    ]
+
+    # Directory lookup returns the room id
+    mock_get.return_value = _resp(
+        requests.codes.ok,
+        dumps({"room_id": "!abc123:matrix.vip"}),
+    )
+
+    # Sending the message succeeds (v3 uses PUT)
+    mock_put.return_value = _resp(requests.codes.ok, dumps({}))
+
+    ap = Apprise()
+    ap.add("matrixs://user:pass@matrix.vip/#backup?discovery=no")
+
+    assert ap.notify(title="t", body="b") is True
+
+    import gc
+
+    del ap
+    gc.collect()
+
+    # login + join + createRoom + logout
+    assert mock_post.call_count == 4
+    assert mock_get.call_count == 1
+    assert mock_put.call_count == 1
