@@ -149,6 +149,14 @@ apprise_url_tests = (
             "requests_response_text": GOOD_RESPONSE_TEXT,
         },
     ),
+    # Actions
+    (
+        "ntfy://localhost/topic1/?actions=view%2CExample%2Chttp://www.example.com/%3Bview%2CTest%2Chttp://www.test.com/",
+        {
+            "instance": NotifyNtfy,
+            "requests_response_text": GOOD_RESPONSE_TEXT,
+        },
+    ),
     # Delay
     (
         "ntfy://localhost/topic1/?delay=3600",
@@ -386,7 +394,7 @@ apprise_url_tests = (
         "ntfy://user:pass@localhost:8082/topic",
         {
             "instance": NotifyNtfy,
-            # throw a bizzare code forcing us to fail to look it up
+            # throw a bizarre code forcing us to fail to look it up
             "response": False,
             "requests_response_code": 999,
             "requests_response_text": GOOD_RESPONSE_TEXT,
@@ -397,7 +405,7 @@ apprise_url_tests = (
         {
             "instance": NotifyNtfy,
             # Throws a series of i/o exceptions with this flag
-            # is set and tests that we gracfully handle them
+            # is set and tests that we gracefully handle them
             "test_requests_exceptions": True,
             "requests_response_text": GOOD_RESPONSE_TEXT,
         },
